@@ -79,7 +79,6 @@ class RobotCompletionProtocolPart(RobotLanguageServerProtocolPart):
     async def get_section_style(self, document: TextDocument) -> str:
         if (folder := self.parent.workspace.get_workspace_folder(document.uri)) is not None:
             config = await self.parent.workspace.get_configuration(SyntaxConfig, folder.uri)
-
             return config.section_style or DEFAULT_SECTIONS_STYLE
 
         return DEFAULT_SECTIONS_STYLE
@@ -1662,7 +1661,7 @@ class CompletionCollector(ModelHelperMixin):
             return None
 
         if (
-            token_at_position.type == RobotToken.EOL
+            token_at_position.type in [RobotToken.EOL, RobotToken.SEPARATOR]
             and len(tokens_at_position) > 1
             and tokens_at_position[-2].type == RobotToken.KEYWORD
         ):
